@@ -1,2 +1,2 @@
 def fixturefunc():
-    pass
+    """ """
